@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2019-01-17'; # DATE
-our $VERSION = '0.342'; # VERSION
+our $DATE = '2021-06-23'; # DATE
+our $VERSION = '0.343'; # VERSION
 
 use 5.010001;
 use strict;
@@ -230,7 +230,7 @@ Config::IOD::Reader - Read IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.342 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2019-01-17.
+This document describes version 0.343 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2021-06-23.
 
 =head1 SYNOPSIS
 
@@ -316,6 +316,12 @@ refer to the already mentioned key.
 Code will be compiled using Perl's C<eval()> in the
 C<Config::IOD::Expr::_Compiled> namespace, with C<no strict>, C<no warnings>.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <sharyanto@cpan.org>
+
 =head1 ATTRIBUTES
 
 =head2 default_section => str (default: C<GLOBAL>)
@@ -416,7 +422,7 @@ you'll also need to set C<enable_expr> to 1.
 
 =head2 enable_expr => bool (default: 0)
 
-Whether to enable C<expr> encoding. By default this is turned on, for safety.
+Whether to enable C<expr> encoding. By default this is turned off, for safety.
 Please see L</"EXPRESSION"> for more details.
 
 =head2 allow_directives => array
@@ -551,7 +557,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
